@@ -5,11 +5,15 @@
 # Copyright (C) 2000-2005 David Beckett - http://www.dajobe.org/
 # Copyright (C) 2000-2005 University of Bristol - http://www.bristol.ac.uk/
 # 
-# This package is Free Software or Open Source available under the
-# following licenses (these are alternatives):
-#   1. GNU Lesser General Public License (LGPL)
-#   2. GNU General Public License (GPL)
-#   3. Mozilla Public License (MPL)
+# This package is Free Software and part of Redland http://librdf.org/
+# 
+# It is licensed under the following three licenses as alternatives:
+#   1. GNU Lesser General Public License (LGPL) V2.1 or any newer version
+#   2. GNU General Public License (GPL) V2 or any newer version
+#   3. Apache License, V2.0 or any newer version
+# 
+# You may not use this file except in compliance with at least one of
+# the above three licenses.
 # 
 # See LICENSE.html or LICENSE.txt at the top of this package for the
 # full license terms.
@@ -42,7 +46,12 @@ sub new ($) {
   my $class = ref($proto) || $proto;
   my $self  = {};
 
-  $self->{WORLD}=&RDF::Redland::CORE::librdf_new_world();
+  # This line is needed because otherwise will perl will barf a
+  # warning (that CANNOT be disabled with no warnings 'once') about
+  # an unused variable.
+  $_p_librdf_world_s::OWNER = 1;
+
+  $self->{WORLD} = &RDF::Redland::CORE::librdf_new_world();
   &RDF::Redland::CORE::librdf_world_open($self->{WORLD});
 
   &RDF::Redland::CORE::librdf_perl_world_init($self->{WORLD});
@@ -83,7 +92,7 @@ package RDF::Redland;
 
 use vars qw($VERSION $Debug $World $Error_Sub $Warning_Sub);
 
-$VERSION= eval sprintf("%s.%02d_%02d_%02d", split(/\./, "1.0.8.1"));
+$VERSION= eval sprintf("%s.%02d_%02d_%02d", split(/\./, "1.0.16.1"));
 
 $Debug=0;
 
