@@ -5,11 +5,15 @@
 # Copyright (C) 2000-2005 David Beckett - http://www.dajobe.org/
 # Copyright (C) 2000-2005 University of Bristol - http://www.bristol.ac.uk/
 # 
-# This package is Free Software or Open Source available under the
-# following licenses (these are alternatives):
-#   1. GNU Lesser General Public License (LGPL)
-#   2. GNU General Public License (GPL)
-#   3. Mozilla Public License (MPL)
+# This package is Free Software and part of Redland http://librdf.org/
+# 
+# It is licensed under the following three licenses as alternatives:
+#   1. GNU Lesser General Public License (LGPL) V2.1 or any newer version
+#   2. GNU General Public License (GPL) V2 or any newer version
+#   3. Apache License, V2.0 or any newer version
+# 
+# You may not use this file except in compliance with at least one of
+# the above three licenses.
 # 
 # See LICENSE.html or LICENSE.txt at the top of this package for the
 # full license terms.
@@ -20,6 +24,7 @@
 package RDF::Redland::Node;
 
 use strict;
+use Encode;
 
 use vars qw($Type_Resource $Type_Property $Type_Literal
 	    $Type_Statement $Type_Blank);
@@ -397,7 +402,7 @@ $RDF::Redland::Node::Type_Literal)
 =cut
 
 sub literal_value ($) {
-  &RDF::Redland::CORE::librdf_node_get_literal_value(shift->{NODE});
+  return decode_utf8(&RDF::Redland::CORE::librdf_node_get_literal_value(shift->{NODE}));
 }
 
 =item literal_value_as_latin1
@@ -453,7 +458,8 @@ Return the RDF::Redland::Node formatted as a string (UTF-8 encoded).
 =cut
 
 sub as_string ($) {
-  &RDF::Redland::CORE::librdf_node_to_string(shift->{NODE});
+  my $v = decode_utf8(&RDF::Redland::CORE::librdf_node_to_string(shift->{NODE}));
+  return $v;
 }
 
 =item equals NODE
