@@ -1,9 +1,7 @@
 # 
 # RDF.py - Redland Python RDF module
 #
-# $Id: RDF.py 12479 2007-08-25 04:27:59Z dajobe $
-#
-# Copyright (C) 2000-2006 David Beckett - http://purl.org/net/dajobe/
+# Copyright (C) 2000-2011 David Beckett - http://www.dajobe.org/
 # Copyright (C) 2000-2005 University of Bristol - http://www.bristol.ac.uk/
 # 
 # This package is Free Software and part of Redland http://librdf.org/
@@ -19,8 +17,6 @@
 #      from http://www.opensource.org/licenses/mit-license.html
 #
 #      -------------------------------------------------------------------
-#      Copyright (c) 2000-2005, David Beckett, ILRT, University of Bristol
-#
 #      Permission is hereby granted, free of charge, to any person
 #      obtaining a copy of this software and associated documentation
 #      files (the "Software"), to deal in the Software without
@@ -46,9 +42,8 @@
 # the above four licenses.
 # 
 # See LICENSE.html or LICENSE.txt at the top of this package for the
-# complete terms and further detail along with the license texts for
-# the licenses in COPYING.LIB, COPYING and LICENSE-2.0.txt respectively.
-# 
+# full license terms.
+#
 #
 
 from __future__ import generators
@@ -109,8 +104,8 @@ __all__ = [ "Node",
 __version__ = "1.1"
 
 # For pydoc
-__date__ = '$Date: 2007-08-24 21:27:59 -0700 (Fri, 24 Aug 2007) $'
-__author__ = 'Dave Beckett - http://purl.org/net/dajobe, Edd Dumbill <edd@usefulinc.com> and Matt Biddulph <mb@picdiary.com>'
+__date__ = '$Date$'
+__author__ = 'Dave Beckett - http://www.dajobe.org/, Edd Dumbill <edd@usefulinc.com> and Matt Biddulph <mb@picdiary.com>'
 
 # Package variables [globals]
 #   Python style says to use _ to prevent exporting
@@ -177,7 +172,9 @@ class World(object):
     #trick to ensure function exists during module cleanup
     self._cleanup = Redland.librdf_free_world
 
-    self._world=Redland.librdf_new_world()
+    self._world = None
+
+    self._world = Redland.librdf_new_world()
     Redland.librdf_world_open(self._world)
 
     Redland.librdf_python_world_init(self._world)
@@ -185,9 +182,10 @@ class World(object):
   def __del__(self):
     """Destroy RDF World object (destructor)."""
     global _debug    
-    if _debug:
-      print "Destroying RDF.World"
-    self._cleanup(self._world)
+    if self._world:
+      if _debug:
+        print "Destroying RDF.World"
+      self._cleanup(self._world)
 
 # end class World
 
@@ -265,17 +263,17 @@ class Node(object):
     self._node=None
 
     if arg is not None:
-      if type(arg) is str:
+      if isinstance(arg, str):
         args['literal'] = arg
-      elif type(arg) is unicode:
+      elif isinstance(arg, unicode):
         import Redland_python
         args['literal'] = Redland_python.unicode_to_bytes(arg)
-      elif type(arg) is Uri:
+      elif isinstance(arg, Uri):
         args['uri'] = arg
-      elif type(arg) is Node:
+      elif isinstance(arg, Node):
         args['node'] = arg
 
-    if args.has_key('literal') and type(args['literal']) is unicode:
+    if args.has_key('literal') and isinstance(args['literal'], unicode):
         import Redland_python
         args['literal'] = Redland_python.unicode_to_bytes(args['literal'])
 
@@ -349,13 +347,30 @@ class Node(object):
   uri = property(_get_uri, doc = "The URI of a resource node")
   type = property(_get_type, doc = "The node type, an integer")
 
+  def _get_literal (self):
+    if not self.is_literal():
+      raise NodeTypeError("Can't get literal value for node type %s (%d)" % \
+            (node_type_name(self.type), self.type))
+
+    dt_uri = Redland.librdf_node_get_literal_value_datatype_uri(self._node)
+
+    if dt_uri:
+      dt_uri = Uri(string=Redland.librdf_uri_to_string(dt_uri))
+
+    return (unicode(Redland.librdf_node_get_literal_value(self._node), 'utf-8'),
+            Redland.librdf_node_get_literal_value_language(self._node),
+            dt_uri)
+
   def _get_literal_value (self):
     if not self.is_literal():
       raise NodeTypeError("Can't get literal value for node type %s (%d)" % \
             (node_type_name(self.type), self.type))
-    dt_uri=Redland.librdf_node_get_literal_value_datatype_uri(self._node)
+
+    dt_uri = Redland.librdf_node_get_literal_value_datatype_uri(self._node)
+
     if dt_uri:
-      dt_uri=Uri(string=Redland.librdf_uri_to_string(dt_uri))
+      dt_uri = Uri(string=Redland.librdf_uri_to_string(dt_uri))
+
     val={
         'string': unicode(Redland.librdf_node_get_literal_value(self._node), 'utf-8'),
         'language': Redland.librdf_node_get_literal_value_language(self._node),
@@ -363,6 +378,9 @@ class Node(object):
         }
     return val
 
+  literal = property(_get_literal,
+          doc = "A tuple of the string, language and datatype values of the node")
+
   literal_value = property(_get_literal_value,
           doc = "A dictionary containing the value of the node literal with keys string, language and datatype")
 
@@ -371,24 +389,28 @@ class Node(object):
       raise NodeTypeError("Can't get blank identifier for node type %s (%d)" % \
             (node_type_name(self.type), self.type))
     else:
-      return Redland.librdf_node_get_blank_identifier(self._node)
+      return unicode(Redland.librdf_node_get_blank_identifier(self._node), 'utf-8')
+
+  blank = property(_get_blank_identifier, 
+          doc = "The blank node identifier")
 
   blank_identifier = property(_get_blank_identifier, 
           doc = "The node identifier of a blank node")
 
   def __str__(self):
     """Get a string representation of an RDF Node."""
-    if self._node is None:
-      raise RedlandError("Node is invalid") 
-    else:
-      return Redland.librdf_node_to_string(self._node)
+    return unicode(self).encode('utf-8')
 
   def __unicode__(self):
     """Get a Unicode string representation of an RDF Node."""
     if self._node is None:
       raise RedlandError("Node is invalid") 
+    elif self.is_literal():
+      return unicode(Redland.librdf_node_get_literal_value(self._node), 'utf-8')
+    elif self.is_blank():
+      return self._get_blank_identifier()
     else:
-      return unicode(Redland.librdf_node_to_string(self._node), 'utf-8')
+      return unicode(self.uri)
 
   def __eq__(self,other):
     """Equality of an RDF Node compared to another RDF Node."""
@@ -468,9 +490,9 @@ class Statement(object):
       if subject is None:
         s = None
       else:
-        if type(subject) is Uri or type(subject) is str:
+        if isinstance(subject, Uri) or isinstance(subject, str):
           subject = Node(subject)
-        elif type(subject) is unicode:
+        elif isinstance(subject, unicode):
           import Redland_python
           subject = Node(Redland_python.unicode_to_bytes(subject))
         s = Redland.librdf_new_node_from_node(subject._node)
@@ -478,9 +500,9 @@ class Statement(object):
       if predicate is None:
         p = None
       else:
-        if type(predicate) is Uri or type(predicate) is str:
+        if isinstance(predicate, Uri) or isinstance(predicate, str):
           predicate = Node(predicate)
-        elif type(predicate) is unicode:
+        elif isinstance(predicate, unicode):
           import Redland_python
           predicate = Node(Redland_python.unicode_to_bytes(predicate))
         p = Redland.librdf_new_node_from_node(predicate._node)
@@ -488,9 +510,9 @@ class Statement(object):
       if object is None:
         o = None
       else:
-        if type(object) is Uri or type(object) is str:
+        if isinstance(object, Uri) or isinstance(object, str):
           object = Node(object)
-        elif type(object) is unicode:
+        elif isinstance(object, unicode):
           import Redland_python
           object = Node(Redland_python.unicode_to_bytes(object))
         o = Redland.librdf_new_node_from_node(object._node)
@@ -769,7 +791,7 @@ Create a model using an in-memory storage.
                                                    statement._statement)
 
   def __delitem__(self, arg):
-    if type(arg) is tuple:
+    if isinstance(arg, tuple):
       try:
         (s, c) = arg
         self.remove_statement(s, c)
@@ -801,7 +823,7 @@ Create a model using an in-memory storage.
   def __contains__(self, arg):
     # provided here for efficiency, otherwise Python
     # would iterate through the contents of the model
-    if type(arg) is tuple:
+    if isinstance(arg, tuple):
       try:
         (s, c) = arg
         return self.contains_statement_context(s, c)
@@ -885,11 +907,11 @@ Create a model using an in-memory storage.
        e.g.
          model.get_sources(Uri("http://example.com/name"), "Fred")
     """
-    if type(predicate) is Uri:
+    if isinstance(predicate, Uri):
       predicate = Node(predicate)
-    if type(target) is Uri or type(target) is str:
+    if isinstance(target, Uri) or isinstance(target, str):
       target = Node(target)
-    elif type(target) is unicode:
+    elif isinstance(target, unicode):
       import Redland_python
       target = Node(Redland_python.unicode_to_bytes(target))
 
@@ -918,11 +940,11 @@ Create a model using an in-memory storage.
        e.g.
          model.get_predicates(Uri("http://example.com/me"), "Fred")
     """
-    if type(source) is Uri:
+    if isinstance(source, Uri):
       source = Node(source)
-    if type(target) is Uri or type(target) is str:
+    if isinstance(target, Uri) or isinstance(target, str):
       target = Node(target)
-    elif type(target) is unicode:
+    elif isinstance(target, unicode):
       import Redland_python
       target = Node(Redland_python.unicode_to_bytes(target))
 
@@ -953,9 +975,9 @@ Create a model using an in-memory storage.
 
          model.get_targets(Uri("http://example.com/me"), prednode)
     """
-    if type(source) is Uri:
+    if isinstance(source, Uri):
       source = Node(source)
-    if type(predicate) is Uri:
+    if isinstance(predicate, Uri):
       predicate = Node(predicate)
 
     my_iterator = Redland.librdf_model_get_targets(self._model, source._node,
@@ -975,11 +997,11 @@ Create a model using an in-memory storage.
   def get_source(self, predicate, target):
     """Return one Node in the Model matching (?, predicate, target).
     The predicate can be a Node or Uri, the target a Node, Uri or string."""
-    if type(predicate) is Uri:
+    if isinstance(predicate, Uri):
       predicate = Node(predicate)
-    if type(target) is Uri or type(target) is str:
+    if isinstance(target, Uri) or isinstance(target, str):
       target = Node(target)
-    elif type(target) is unicode:
+    elif isinstance(target, unicode):
       import Redland_python
       target = Node(Redland_python.unicode_to_bytes(target))
 
@@ -993,11 +1015,11 @@ Create a model using an in-memory storage.
   def get_predicate(self,source,target):
     """Return one Node in the Model matching (source, ?, target).
     The source can be a Node or Uri, the target a Node, Uri or string."""
-    if type(source) is Uri:
+    if isinstance(source, Uri):
       source = Node(source)
-    if type(target) is Uri or type(target) is str:
+    if isinstance(target, Uri) or isinstance(target, str):
       target = Node(target)
-    elif type(target) is unicode:
+    elif isinstance(target, unicode):
       import Redland_python
       target = Node(Redland_python.unicode_to_bytes(target))
 
@@ -1013,9 +1035,9 @@ Create a model using an in-memory storage.
   def get_target(self, source, predicate):
     """Return one Node in the Model matching (source, predicate, ?).
     The source and predicate can be a Node or Uri."""
-    if type(source) is Uri:
+    if isinstance(source, Uri):
       source = Node(source)
-    if type(predicate) is Uri:
+    if isinstance(predicate, Uri):
       predicate = Node(predicate)
 
     my_node=Redland.librdf_model_get_target(self._model, source._node,
@@ -1066,18 +1088,18 @@ Create a model using an in-memory storage.
          def handler(code, level, facility, message, line, column, byte, file, uri)
        is called.
    """
-    if type(uri) is str:
+    if isinstance(uri, str):
       uri = Uri(string=uri)
-    elif type(uri) is unicode:
+    elif isinstance(uri, unicode):
       import Redland_python
       uri = Uri(string=Redland_python.unicode_to_bytes(uri))
     if uri is None:
       raise TypeError("uri must be a string or RDF.Uri")
     ruri = uri._reduri
 
-    if type(type_uri) is str:
+    if isinstance(type_uri, str):
       type_uri = Uri(string=type_uri)
-    elif type(type_uri) is unicode:
+    elif isinstance(type_uri, unicode):
       import Redland_python
       type_uri = Uri(string=Redland_python.unicode_to_bytes(type_uri))
     if type_uri is not None:
@@ -1104,18 +1126,18 @@ Create a model using an in-memory storage.
 
        If no serializer name is given, the default serializer RDF/XML is used.
    """
-    if type(base_uri) is str:
+    if isinstance(base_uri, str):
       base_uri = Uri(string=base_uri)
-    elif type(base_uri) is unicode:
+    elif isinstance(base_uri, unicode):
       import Redland_python
       base_uri = Uri(string=Redland_python.unicode_to_bytes(base_uri))
     if base_uri is not None:
       rbase_uri = base_uri._reduri
     else:
       rbase_uri = None
-    if type(type_uri) is str:
+    if isinstance(type_uri, str):
       type_uri = Uri(string=type_uri)
-    elif type(type_uri) is unicode:
+    elif isinstance(type_uri, unicode):
       import Redland_python
       type_uri = Uri(string=Redland_python.unicode_to_bytes(type_uri))
     if type_uri is not None:
@@ -1174,6 +1196,7 @@ class Iterator(object):
     global _debug    
     if _debug:
       print "Creating RDF.Iterator object=",object,"creator=",creator1
+
     self._iterator=object
     # keep references to the things we're iterating over so they
     # don't get destroyed before we're done with them.
@@ -1188,7 +1211,8 @@ class Iterator(object):
     global _debug    
     if _debug:
       print "Destroying RDF.Iterator"
-    Redland.librdf_free_iterator(self._iterator)
+    if self._iterator:
+      Redland.librdf_free_iterator(self._iterator)
 
   def end(self):
     """Return true if the iterator is exhausted"""
@@ -1588,12 +1612,12 @@ Copy an existing URI uri1.
     self._reduri=None
 
     if arg is not None:
-      if type(arg) is str:
+      if isinstance(arg, str):
         args['string'] = arg
-      elif type(arg) is unicode:
+      elif isinstance(arg, unicode):
         import Redland_python
         args['string'] = Redland_python.unicode_to_bytes(arg)
-      elif type(arg) is Uri:
+      elif isinstance(arg, Uri):
         args['uri'] = arg
 
     if args.has_key('string') and args['string'] is not None:
@@ -1675,6 +1699,8 @@ standard configuration of Raptor.
     if _debug:
       print "Creating RDF.Parser name=",name,"mime_type=",mime_type, "uri=",uri
 
+    self._parser = None
+
     if uri is not None:
       ruri=uri._reduri
     else:
@@ -1700,9 +1726,9 @@ standard configuration of Raptor.
           for statement in parser.parse_as_stream("http://localhost/r.rdf"):
               print statement
     """
-    if type(uri) is str:
+    if isinstance(uri, str):
       uri = Uri(string=uri)
-    elif type(uri) is unicode:
+    elif isinstance(uri, unicode):
       import Redland_python
       uri = Uri(string=Redland_python.unicode_to_bytes(uri))
     if base_uri is None:
@@ -1720,15 +1746,15 @@ standard configuration of Raptor.
           for statement in parser.parse_string_as_stream(rdfstring, base_uri):
               print statement
     """
-    if type(base_uri) is str:
+    if isinstance(base_uri, str):
       base_uri = Uri(string=base_uri)
-    elif type(base_uri) is unicode:
+    elif isinstance(base_uri, unicode):
       import Redland_python
       base_uri = Uri(string=Redland_python.unicode_to_bytes(base_uri))
     if base_uri is None:
       raise RedlandError("A base URI is required when parsing a string")
 
-    if type(string) is unicode:
+    if isinstance(string, unicode):
       import Redland_python
       string=Redland_python.unicode_to_bytes(string)
 
@@ -1750,14 +1776,14 @@ standard configuration of Raptor.
                                "http://example.com/foo.rdf")
     """
 
-    if type(uri) is str:
+    if isinstance(uri, str):
       uri = Uri(string = uri)
-    elif type(uri) is unicode:
+    elif isinstance(uri, unicode):
       import Redland_python
       uri = Uri(string=Redland_python.unicode_to_bytes(uri))
-    if type(base_uri) is str:
+    if isinstance(base_uri, str):
       base_uri = Uri(string = base_uri)
-    elif type(base_uri) is unicode:
+    elif isinstance(base_uri, unicode):
       import Redland_python
       base_uri = Uri(string=Redland_python.unicode_to_bytes(base_uri))
     if base_uri is None:
@@ -1789,9 +1815,9 @@ standard configuration of Raptor.
        is called.
 
     """
-    if type(base_uri) is str:
+    if isinstance(base_uri, str):
       base_uri = Uri(string = base_uri)
-    elif type(base_uri) is unicode:
+    elif isinstance(base_uri, unicode):
       import Redland_python
       base_uri = Uri(string=Redland_python.unicode_to_bytes(base_uri))
     if base_uri is None:
@@ -1801,7 +1827,7 @@ standard configuration of Raptor.
       import Redland_python
       Redland_python.set_callback(handler)
 
-    if type(string) is unicode:
+    if isinstance(string, unicode):
       import Redland_python
       string=Redland_python.unicode_to_bytes(string)
 
@@ -1847,6 +1873,21 @@ standard configuration of Raptor.
     import Redland_python
     Redland_python.set_parser_uri_filter(self._parser, filter)
 
+  def namespaces_seen(self):
+    """Get a dictionary of prefix/URI pairs for namespaces seen during parsing.
+"""
+    count = Redland.librdf_parser_get_namespaces_seen_count(self._parser)
+    nspaces={}
+    for index in range(0, count-1):
+      prefix=Redland.librdf_parser_get_namespaces_seen_prefix(self._parser, index)
+      uri_obj=Redland.librdf_parser_get_namespaces_seen_uri(self._parser, index)
+      if uri_obj is None:
+        uri=None
+      else:
+        uri=Uri(from_object=uri_obj)
+      nspaces[prefix]=uri
+    return nspaces
+
 # end class Parser
 
 class RDFXMLParser(Parser):
@@ -1913,22 +1954,33 @@ class Query(object):
     print statement
 
   """
-  def __init__(self, querystring, base_uri=None, query_language="rdql", query_uri=None):
+  def __init__(self, querystring, base_uri=None, query_language="sparql", query_uri=None):
+    self._query = None
+
+    if querystring is None:
+      raise RedlandError("No query string given")
+
+    if isinstance(querystring, unicode): 
+      querystring = querystring.encode('utf-8')
+
     if query_uri is not None:
       ruri = query_uri._reduri
     else:
       ruri = None
+
     if base_uri is not None:
       rbase_uri = base_uri._reduri
     else:
       rbase_uri = None
+
     global _world
-    global _debug    
+    global _debug
     if _debug:
       print "Creating query for language '"+query_language+"', base '"+str(rbase_uri)+"': "+querystring
 
     self._query = Redland.librdf_new_query(_world._world, query_language, ruri, querystring, rbase_uri)
     self.result_stream = None
+
     if self._query is None:
       raise RedlandError("Query construction failed")
 
@@ -1991,10 +2043,8 @@ class QueryResults(object):
     return self
 
   def __len__(self):
-    """Get the number of query results returned so far (bindings results)"""
-    if self.is_bindings:
-      return Redland.librdf_query_results_get_count(self._results)
-    return 0
+    """Returns an exception since len() of an iterable is undefined."""
+    raise ValueError("Cannot take the length of iterable query results")
 
   # Iterator method
   def next(self):
@@ -2079,15 +2129,15 @@ class QueryResults(object):
   def __del__(self):
     global _debug    
     if _debug:
-      print "Destroying RDF.QueryResults"""
+      print "Destroying RDF.QueryResults"
     if self._results:
       Redland.librdf_free_query_results(self._results)
 
   def to_file(self, name, format_uri=None, base_uri=None):
     """Serialize to filename name in syntax format_uri using the optional base URI."""
-    if type(format_uri) is str:
+    if isinstance(format_uri, str):
       format_uri = Uri(string = format_uri)
-    elif type(format_uri) is unicode:
+    elif isinstance(format_uri, unicode):
       import Redland_python
       format_uri = Uri(string=Redland_python.unicode_to_bytes(format_uri))
     else:
@@ -2098,9 +2148,9 @@ class QueryResults(object):
     else:
       rformat_uri = None
 
-    if type(base_uri) is str:
+    if isinstance(base_uri, str):
       base_uri = Uri(string = base_uri)
-    elif type(base_uri) is unicode:
+    elif isinstance(base_uri, unicode):
       import Redland_python
       base_uri = Uri(string=Redland_python.unicode_to_bytes(base_uri))
     if base_uri is not None:
@@ -2123,9 +2173,9 @@ class QueryResults(object):
     if not self.is_bindings():
       raise RedlandError("Unknown query result format cannot be written as a string")
     
-    if type(format_uri) is str:
+    if isinstance(format_uri, str):
       format_uri = Uri(string = format_uri)
-    elif type(format_uri) is unicode:
+    elif isinstance(format_uri, unicode):
       import Redland_python
       format_uri = Uri(string=Redland_python.unicode_to_bytes(format_uri))
     else:
@@ -2135,17 +2185,18 @@ class QueryResults(object):
       rformat_uri = format_uri._reduri
     else:
       rformat_uri = None
-    if type(base_uri) is str:
+    if isinstance(base_uri, str):
       base_uri = Uri(string = base_uri)
-    elif type(base_uri) is unicode:
+    elif isinstance(base_uri, unicode):
       import Redland_python
       base_uri = Uri(string=Redland_python.unicode_to_bytes(base_uri))
     if base_uri is not None:
       rbase_uri = base_uri._reduri
     else:
       rbase_uri = None
-      return Redland.librdf_query_results_to_string(self._results,
-                                                    rformat_uri, rbase_uri)
+
+    return Redland.librdf_query_results_to_string(self._results,
+                                                  rformat_uri, rbase_uri)
 
   def __str__(self):
     """Serialize to string syntax format."""
@@ -2186,6 +2237,8 @@ class Serializer(object):
       print "Creating RDF.Serializer name=",name,"mime_type=",mime_type, \
         "uri=",uri
 
+    self._serializer = None
+
     if uri is not None:
       ruri = uri._reduri
     else:
@@ -2206,9 +2259,9 @@ class Serializer(object):
   def serialize_model_to_file(self, name, model, base_uri=None):
     """Serialize to filename name the Model model using the
        optional base URI."""
-    if type(base_uri) is str:
+    if isinstance(base_uri, str):
       base_uri = Uri(string = base_uri)
-    elif type(base_uri) is unicode:
+    elif isinstance(base_uri, unicode):
       import Redland_python
       base_uri = Uri(string=Redland_python.unicode_to_bytes(base_uri))
     if base_uri is not None:
@@ -2220,9 +2273,9 @@ class Serializer(object):
 
   def serialize_model_to_string(self, model, base_uri=None):
     """Serialize to a string using the optional base URI."""
-    if type(base_uri) is str:
+    if isinstance(base_uri, str):
       base_uri = Uri(string = base_uri)
-    elif type(base_uri) is unicode:
+    elif isinstance(base_uri, unicode):
       import Redland_python
       base_uri = Uri(string=Redland_python.unicode_to_bytes(base_uri))
     if base_uri is not None:
@@ -2230,15 +2283,28 @@ class Serializer(object):
     else:
       rbase_uri = None
     return Redland.librdf_serializer_serialize_model_to_string(self._serializer, rbase_uri, model._model)
-
+  
+  def serialize_stream_to_string(self, stream, base_uri=None):
+    """Serialize a stream to a string using the optional base URI."""
+    if isinstance(base_uri, str):
+      base_uri = Uri(string = base_uri)
+    elif isinstance(base_uri, unicode):
+      import Redland_python
+      base_uri = Uri(string=Redland_python.unicode_to_bytes(base_uri))
+    if base_uri is not None:
+      rbase_uri = base_uri._reduri
+    else:
+      rbase_uri = None
+    return Redland.librdf_serializer_serialize_stream_to_string(self._serializer, rbase_uri, stream._stream)
+  
   # TODO: features could usefully be implemented as a collection
 
   def get_feature(self, uri):
     """Return the value of Serializer feature URI uri"""
     if not isinstance(uri, Uri):
-      if type(uri) is str:
+      if isinstance(uri, str):
         uri = Uri(string=uri)
-      elif type(uri) is unicode:
+      elif isinstance(uri, unicode):
         import Redland_python
         uri = Uri(string=Redland_python.unicode_to_bytes(uri))
       else:
@@ -2249,9 +2315,9 @@ class Serializer(object):
   def set_feature(self, uri, value):
     """Set the value of Serializer feature URI uri."""
     if not isinstance(uri, Uri):
-      if type(uri) is str:
+      if isinstance(uri, str):
         uri = Uri(string=uri)
-      elif type(uri) is unicode:
+      elif isinstance(uri, unicode):
         import Redland_python
         uri = Uri(string=Redland_python.unicode_to_bytes(uri))
       else:
@@ -2261,9 +2327,9 @@ class Serializer(object):
   def set_namespace(self, prefix, uri):
     """Set a namespace prefix and URI for the Serializer to use."""
     if not isinstance(uri, Uri):
-      if type(uri) is str:
+      if isinstance(uri, str):
         uri = Uri(string=uri)
-      elif type(uri) is unicode:
+      elif isinstance(uri, unicode):
         import Redland_python
         uri = Uri(string=Redland_python.unicode_to_bytes(uri))
       else:
