@@ -272,81 +272,6 @@ class RasqalQueryTestCase (unittest.TestCase):
         a = "file:../data/dc.rdf"
         self.parser.parse_into_model(self.model,a)
 
-    def testCreate(self):
-        q = RDQLQuery("SELECT ?a ?b ?c WHERE (?a ?b ?c)")
-        self.assert_(q is not None)
-        q = Query("- - -",query_language="triples")
-        self.assert_(q is not None)
-
-    def testRDQLQueryCount(self):
-        q = RDQLQuery("SELECT ?x ?y ?z WHERE (?x ?y ?z)")
-        results = q.execute(self.model)
-        for result in results:
-            pass
-        self.assert_(len(results) == 3, "Query count should be 3 after query finished running")
-
-    def testRDQLQueryRun(self):
-        q = RDQLQuery("SELECT ?x ?y ?z WHERE (?x ?y ?z)")
-        results = q.execute(self.model)
-        self.assert_(results is not None,"Query eval not OK")
-
-        count = 0
-        for result in results:
-            count += 1
-        self.assert_(count == 3, "Should have found three results in query")
-
-    def testTripleQueryAsBindingsDontWork(self):
-        q = Query("- - -",query_language="triples")
-        results = q.execute(self.model)
-	first = results.get_binding_name(0)
-        self.assert_(first is None,"Triples queries shouldn't work as bindings - None should be returned from get_binding_name(0)")
-
-    def testRDQLQueryAsStreamDontWork(self):
-        q = RDQLQuery("SELECT ?a ?c WHERE (?a dc:title ?c) USING dc FOR <http://purl.org/dc/elements/1.1/>")
-	failed = False
-	try:
-          stream = q.execute(self.model).as_stream()
-	except:
-          failed = True
-        self.assert_(failed is True,"RDQL queries shouldn't work as streams - None should be returned from as_stream")
-
-    #def testRDQLParseError(self):
-        #q = RDQLQuery("SELECT WHERE")
-        #results = q.run_as_bindings(self.model)
-        # TODO: This needs to fail somehow
-
-    def testTripleQuery(self):
-        q = Query("- - -",query_language="triples")
-        results = q.execute(self.model)
-        stream = results.as_stream()
-        self.assert_(stream is not None,"Query eval not OK")
-
-        count = 0
-        for result in stream:
-            count += 1
-        self.assert_(count == 3, "Should have found three results in query")
-
-    def testRDQLQueryRunOnModel(self):
-        q = RDQLQuery("SELECT ?x ?y ?z WHERE (?x ?y ?z)")
-        bindings = self.model.execute(q)
-        self.assert_(bindings is not None,"Query eval not OK")
-
-        count = 0
-        for result in bindings:
-            count += 1
-        self.assert_(count == 3, "Should have found three results in query")
-
-    def testTripleQueryOnModel(self):
-        q = Query("- - -",query_language="triples")
-        results = self.model.execute(q)
-        stream = results.as_stream()
-        self.assert_(results is not None,"Query eval not OK")
-
-        count = 0
-        for result in stream:
-            count += 1
-        self.assert_(count == 3, "Should have found three results in query")
-
     def testSPARQLQueryAsStream(self):
         q = SPARQLQuery("PREFIX dc: <http://purl.org/dc/elements/1.1/> CONSTRUCT {?a dc:title ?c} WHERE {?a dc:title ?c}")
         s = q.execute(self.model).as_stream()
