@@ -14,14 +14,14 @@ class TestQuery < Test::Unit::TestCase
   def test_model_query_api()
     model = Model.new()
 
-    query = Query.new("SELECT ?a ?b ?c WHERE (?a ?b ?c)", "rdql", nil, nil)
+    query = Query.new("SELECT ?a ?b ?c WHERE { ?a ?b ?c}", "sparql", nil, nil)
     results = query.execute(model)
   end
 
   def test_query_api()
     model = Model.new()
 
-    query = Query.new("SELECT ?a ?b ?c WHERE (?a ?b ?c)", "rdql", nil, nil)
+    query = Query.new("SELECT ?a ?b ?c WHERE { ?a ?b ?c} ", "sparql", nil, nil)
     results = model.query_execute(query)
   end
 
@@ -32,13 +32,13 @@ class TestQuery < Test::Unit::TestCase
     st = Statement.new(@exns['subject'], @exns['pred'], lit)
     model.add_statement(st)
 
-    query = Query.new("SELECT ?a ?b ?c WHERE (?a ?b ?c)", "rdql", nil, nil)
+    query = Query.new("SELECT ?a ?b ?c WHERE { ?a ?b ?c }", "sparql", nil, nil)
     results = query.execute(model)
     assert(results != nil)
 
     # Result should be a single variable binding result with three values
-
     assert(results.is_bindings?)
+    assert_equal(3, results.bindings_count)
     assert_equal(results.binding_value(0), @exns['subject'])
     assert_equal(results.binding_value(1), @exns['pred'])
     assert_equal(results.binding_value(2), lit)
@@ -103,6 +103,7 @@ class TestQuery < Test::Unit::TestCase
     assert(stream.end?)
   end
 
+
   def test_model_query_serialize_bindings()
     model = Model.new()
 
@@ -110,16 +111,23 @@ class TestQuery < Test::Unit::TestCase
     st = Statement.new(@exns['subject'], @exns['pred'], lit)
     model.add_statement(st)
 
-    query = Query.new("SELECT ?a ?b ?c WHERE (?a ?b ?c)", "rdql", nil, nil)
+    query = Query.new("SELECT ?s ?p ?o WHERE {?s ?p ?o}", "sparql", nil, nil)
     results = query.execute(model)
     assert(results != nil)
 
-    string = results.to_string()
+    string = results.to_string(
+      Uri.new("http://www.w3.org/2005/sparql-results#"),
+      Uri.new("http://example.org/")
+    )
 
     # length of a SPARQL results format string - might change
-    assert_equal(string.length(), 449)
+    assert(string.length() > 400)
+    assert_match(%r|<binding name="s"><uri>http://example.org/subject</uri></binding>|, string)
+    assert_match(%r|<binding name="p"><uri>http://example.org/pred</uri></binding>|, string)
+    assert_match(%r|<binding name="o"><literal>baz</literal></binding>|, string)
   end
 
+
   def test_model_query_serialize_ask()
     model = Model.new()
 
@@ -131,12 +139,14 @@ class TestQuery < Test::Unit::TestCase
     results = query.execute(model)
     assert(results != nil)
 
-    string = results.to_string()
+    string = results.to_string(Uri.new("http://www.w3.org/2001/sw/DataAccess/json-sparql/"), Uri.new("http://example.org/"))
 
     # length of a SPARQL results format string - might change
-    assert_equal(string.length(), 150)
+    assert(string.length() > 30)
+    assert_match(%r|"boolean" : true|, string)
   end
 
+
   def test_model_query_serialize_construct()
     model = Model.new()
 
@@ -152,9 +162,12 @@ class TestQuery < Test::Unit::TestCase
     string = results.to_string()
 
     # length of an RDF/XML string - might change
-    assert_equal(string.length(), 401)
+    assert(string.length() > 300)
+    assert_match(%r|<ns0:pred xmlns:ns0="http://example.org/">baz</ns0:pred>|, string)
+    assert_match(%r|<ns0:subject xmlns:ns0="http://example.org/">baz</ns0:subject>|, string)
   end
 
+
   def test_model_query_serialize_bindings_json()
     model = Model.new()
 
@@ -162,16 +175,19 @@ class TestQuery < Test::Unit::TestCase
     st = Statement.new(@exns['subject'], @exns['pred'], lit)
     model.add_statement(st)
 
-    query = Query.new("SELECT ?a ?b ?c WHERE (?a ?b ?c)", "rdql", nil, nil)
+    query = Query.new("SELECT ?a ?b ?c WHERE { ?a ?b ?c }", "sparql", nil, nil)
     results = query.execute(model)
     assert(results != nil)
 
     string = results.to_string(Uri.new("http://www.w3.org/2001/sw/DataAccess/json-sparql/"), Uri.new("http://example.org/"))
 
     # length of a SPARQL results format string in JSON - might change
-    assert_equal(string.length(), 353)
+    assert(string.length() > 300)
+    assert_match(%r|"vars": \[ "a", "b", "c" \]|, string)
+    assert_match(%r|"a" : \{ "type": "uri", "value": "http://example.org/subject" \}|, string)
+    assert_match(%r|"b" : \{ "type": "uri", "value": "http://example.org/pred" \}|, string)
+    assert_match(%r|"c" : \{ "type": "literal", "value": "baz" \}|, string)
   end
 
-
 end
 
